TryChunksError

Struct TryChunksError 

pub struct TryChunksError<T, E>(pub Vec<T>, pub E);
Error indicating, that while chunk was collected inner stream produced an error.

Contains all items that were collected before an error occurred, and the stream error itself.

Tuple Fields

0: Vec<T>1: E